# Open Source NLP Sentiment tracker for Robinhood APIs


### Getting Started


You'll need to set 3 environment variables to use this 
   - *ROBINHOOD_PASSWORD* -- your password for Robinhood
   - *ROBINHOOD_EMAIL* -- your Robinhood email
   - *ROBINHOOD_QR_CODE* -- the QR code copied from you Robinhood account
